@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2016 Hayaki Saito
+ * Copyright (c) 2014-2018 Hayaki Saito
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy of
  * this software and associated documentation files (the "Software"), to deal in
@@ -117,7 +117,14 @@ stbi_free(void *p)
 # pragma GCC diagnostic push
 # pragma GCC diagnostic ignored "-Wdouble-promotion"
 #endif
+# if HAVE_DIAGNOSTIC_UNUSED_FUNCTION
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wunused-function"
+#endif
 #include "stb_image.h"
+#if HAVE_DIAGNOSTIC_UNUSED_FUNCTION
+# pragma GCC diagnostic pop
+#endif
 #if HAVE_DIAGNOSTIC_DOUBLE_PROMOTION
 # pragma GCC diagnostic pop
 #endif
@@ -316,12 +323,20 @@ load_png(unsigned char      /* out */ **result,
     }
 
     if (bgcolor) {
+#  if HAVE_DEBUG
+        fprintf(stderr, "background color is specified [%02x, %02x, %02x]\n",
+                bgcolor[0], bgcolor[1], bgcolor[2]);
+#  endif
         background.red = bgcolor[0];
         background.green = bgcolor[1];
         background.blue = bgcolor[2];
         background.gray = (bgcolor[0] + bgcolor[1] + bgcolor[2]) / 3;
     } else if (png_get_bKGD(png_ptr, info_ptr, &default_background) == PNG_INFO_bKGD) {
         memcpy(&background, default_background, sizeof(background));
+#  if HAVE_DEBUG
+        fprintf(stderr, "background color is found [%02x, %02x, %02x]\n",
+                background.red, background.green, background.blue);
+#  endif
     } else {
         background.red = 0;
         background.green = 0;
@@ -632,6 +647,7 @@ end:
 }
 
 
+/* detect whether given chunk is sixel stream */
 static int
 chunk_is_sixel(sixel_chunk_t const *chunk)
 {
@@ -668,6 +684,7 @@ chunk_is_sixel(sixel_chunk_t const *chunk)
 }
 
 
+/* detect whether given chunk is PNM stream */
 static int
 chunk_is_pnm(sixel_chunk_t const *chunk)
 {
@@ -684,6 +701,7 @@ chunk_is_pnm(sixel_chunk_t const *chunk)
 
 
 #if HAVE_LIBPNG
+/* detect whether given chunk is PNG stream */
 static int
 chunk_is_png(sixel_chunk_t const *chunk)
 {
@@ -698,6 +716,7 @@ chunk_is_png(sixel_chunk_t const *chunk)
 #endif  /* HAVE_LIBPNG */
 
 
+/* detect whether given chunk is GIF stream */
 static int
 chunk_is_gif(sixel_chunk_t const *chunk)
 {
@@ -717,6 +736,7 @@ chunk_is_gif(sixel_chunk_t const *chunk)
 
 
 #if HAVE_JPEG
+/* detect whether given chunk is JPEG stream */
 static int
 chunk_is_jpeg(sixel_chunk_t const *chunk)
 {
@@ -859,7 +879,7 @@ load_with_builtin(
         }
         stbi_allocator = pchunk->allocator;
         stbi__start_mem(&s, pchunk->buffer, (int)pchunk->size);
-        frame->pixels = stbi__load_main(&s, &frame->width, &frame->height, &depth, 3);
+        frame->pixels = stbi__load_and_postprocess_8bit(&s, &frame->width, &frame->height, &depth, 3);
         if (!frame->pixels) {
             sixel_helper_set_additional_message(stbi_failure_reason());
             status = SIXEL_STBI_ERROR;
@@ -1367,7 +1387,7 @@ error:
 }
 
 
-int
+SIXELAPI int
 sixel_loader_tests_main(void)
 {
     int nret = EXIT_FAILURE;
