@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014,2015 Hayaki Saito
+ * Copyright (c) 2014-2016 Hayaki Saito
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy of
  * this software and associated documentation files (the "Software"), to deal in
@@ -27,6 +27,7 @@
 #include "output.h"
 
 
+/* create new output context object */
 SIXELAPI SIXELSTATUS
 sixel_output_new(
     sixel_output_t          /* out */ **output,
@@ -58,6 +59,7 @@ sixel_output_new(
     (*output)->ref = 1;
     (*output)->has_8bit_control = 0;
     (*output)->has_sdm_glitch = 0;
+    (*output)->has_gri_arg_limit = 1;
     (*output)->skip_dcs_envelope = 0;
     (*output)->palette_type = SIXEL_PALETTETYPE_AUTO;
     (*output)->fn_write = fn_write;
@@ -79,6 +81,7 @@ end:
 }
 
 
+/* deprecated: create an output object */
 SIXELAPI sixel_output_t *
 sixel_output_create(sixel_write_function fn_write, void *priv)
 {
@@ -95,6 +98,7 @@ end:
 }
 
  
+/* destroy output context object */
 SIXELAPI void
 sixel_output_destroy(sixel_output_t *output)
 {
@@ -108,6 +112,7 @@ sixel_output_destroy(sixel_output_t *output)
 }
 
 
+/* increase reference count of output context object (thread-unsafe) */
 SIXELAPI void
 sixel_output_ref(sixel_output_t *output)
 {
@@ -116,6 +121,7 @@ sixel_output_ref(sixel_output_t *output)
 }
 
 
+/* decrease reference count of output context object (thread-unsafe) */
 SIXELAPI void
 sixel_output_unref(sixel_output_t *output)
 {
@@ -130,6 +136,7 @@ sixel_output_unref(sixel_output_t *output)
 }
 
 
+/* get 8bit output mode which indicates whether it uses C1 control characters */
 SIXELAPI int
 sixel_output_get_8bit_availability(sixel_output_t *output)
 {
@@ -137,6 +144,7 @@ sixel_output_get_8bit_availability(sixel_output_t *output)
 }
 
 
+/* set 8bit output mode state */
 SIXELAPI void
 sixel_output_set_8bit_availability(sixel_output_t *output, int availability)
 {
@@ -144,6 +152,18 @@ sixel_output_set_8bit_availability(sixel_output_t *output, int availability)
 }
 
 
+/* set whether limit arguments of DECGRI('!') to 255 */
+SIXELAPI void
+sixel_output_set_gri_arg_limit(
+    sixel_output_t /* in */ *output, /* output context */
+    int            /* in */ value)   /* 0: don't limit arguments of DECGRI
+                                        1: limit arguments of DECGRI to 255 */
+{
+    output->has_gri_arg_limit = value;
+}
+
+
+/* set GNU Screen penetration feature enable or disable */
 SIXELAPI void
 sixel_output_set_penetrate_multiplexer(sixel_output_t *output, int penetrate)
 {
@@ -151,6 +171,7 @@ sixel_output_set_penetrate_multiplexer(sixel_output_t *output, int penetrate)
 }
 
 
+/* set whether we skip DCS envelope */
 SIXELAPI void
 sixel_output_set_skip_dcs_envelope(sixel_output_t *output, int skip)
 {
@@ -158,6 +179,7 @@ sixel_output_set_skip_dcs_envelope(sixel_output_t *output, int skip)
 }
 
 
+/* set palette type: RGB or HLS */
 SIXELAPI void
 sixel_output_set_palette_type(sixel_output_t *output, int palettetype)
 {
@@ -165,12 +187,18 @@ sixel_output_set_palette_type(sixel_output_t *output, int palettetype)
 }
 
 
+/* set encodeing policy: auto, fast or size */
 SIXELAPI void
 sixel_output_set_encode_policy(sixel_output_t *output, int encode_policy)
 {
     output->encode_policy = encode_policy;
 }
 
-/* emacs, -*- Mode: C; tab-width: 4; indent-tabs-mode: nil -*- */
-/* vim: set expandtab ts=4 : */
+/* emacs Local Variables:      */
+/* emacs mode: c               */
+/* emacs tab-width: 4          */
+/* emacs indent-tabs-mode: nil */
+/* emacs c-basic-offset: 4     */
+/* emacs End:                  */
+/* vim: set expandtab ts=4 sts=4 sw=4 : */
 /* EOF */
