@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014,2015 Hayaki Saito
+ * Copyright (c) 2014-2016 Hayaki Saito
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy of
  * this software and associated documentation files (the "Software"), to deal in
@@ -45,6 +45,10 @@ struct sixel_output {
      * 1: the terminal does not have sixel scrolling */
     unsigned char has_sixel_scrolling;
 
+    /* 1: the argument of repeat introducer(DECGRI) is not limitted
+       0: the argument of repeat introducer(DECGRI) is limitted 255 */
+    unsigned char has_gri_arg_limit;
+
     /* 0: DECSDM set (CSI ? 80 h) enables sixel scrolling
        1: DECSDM set (CSI ? 80 h) disables sixel scrolling */
     unsigned char has_sdm_glitch;
@@ -77,6 +81,11 @@ struct sixel_output {
 
 #endif /* LIBSIXEL_OUTPUT_H */
 
-/* emacs, -*- Mode: C; tab-width: 4; indent-tabs-mode: nil -*- */
-/* vim: set expandtab ts=4 : */
+/* emacs Local Variables:      */
+/* emacs mode: c               */
+/* emacs tab-width: 4          */
+/* emacs indent-tabs-mode: nil */
+/* emacs c-basic-offset: 4     */
+/* emacs End:                  */
+/* vim: set expandtab ts=4 sts=4 sw=4 : */
 /* EOF */
