@@ -22,7 +22,7 @@
  *
  * ******************************************************************************
  *
- * Copyright (c) 2014-2016 Hayaki Saito
+ * Copyright (c) 2014-2018 Hayaki Saito
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy of
  * this software and associated documentation files (the "Software"), to deal in
@@ -737,7 +737,7 @@ computeHistogram(unsigned char const    /* in */  *data,
         goto end;
     }
 
-    for (i = 0; i < length - depth; i += step) {
+    for (i = 0; i < length; i += step) {
         bucket_index = computeHash(data + i, 3);
         if (histogram[bucket_index] == 0) {
             *ref++ = bucket_index;
@@ -1030,6 +1030,17 @@ diffuse_burkes(unsigned char *data, int width, int height,
     }
 }
 
+static float
+mask_a (int x, int y, int c)
+{
+    return ((((x + c * 67) + y * 236) * 119) & 255 ) / 128.0 - 1.0;
+}
+
+static float
+mask_x (int x, int y, int c)
+{
+    return ((((x + c * 29) ^ y* 149) * 1234) & 511 ) / 256.0 - 1.0;
+}
 
 /* lookup closest color from palette with "normal" strategy */
 static int
@@ -1245,13 +1256,15 @@ sixel_quant_apply_palette(
     sixel_allocator_t /* in */  *allocator)
 {
     typedef int component_t;
+    enum { max_depth = 4 };
     SIXELSTATUS status = SIXEL_FALSE;
     int pos, n, x, y, sum1, sum2;
     component_t offset;
     int color_index;
     unsigned short *indextable;
-    unsigned char new_palette[256 * 4];
+    unsigned char new_palette[256 * max_depth];
     unsigned short migration_map[256];
+    float (*f_mask) (int x, int y, int c) = NULL;
     void (*f_diffuse)(unsigned char *data, int width, int height,
                       int x, int y, int depth, int offset);
     int (*f_lookup)(unsigned char const * const pixel,
@@ -1261,6 +1274,15 @@ sixel_quant_apply_palette(
                     unsigned short * const cachetable,
                     int const complexion);
 
+    /* check bad reqcolor */
+    if (reqcolor < 1) {
+        status = SIXEL_BAD_ARGUMENT;
+        sixel_helper_set_additional_message(
+            "sixel_quant_apply_palette: "
+            "a bad argument is detected, reqcolor < 0.");
+        goto end;
+    }
+
     if (depth != 3) {
         f_diffuse = diffuse_none;
     } else {
@@ -1283,6 +1305,14 @@ sixel_quant_apply_palette(
         case SIXEL_DIFFUSE_BURKES:
             f_diffuse = diffuse_burkes;
             break;
+        case SIXEL_DIFFUSE_A_DITHER:
+            f_diffuse = diffuse_none;
+            f_mask = mask_a;
+            break;
+        case SIXEL_DIFFUSE_X_DITHER:
+            f_diffuse = diffuse_none;
+            f_mask = mask_x;
+            break;
         default:
             quant_trace(stderr, "Internal error: invalid value of"
                                 " methodForDiffuse: %d\n",
@@ -1333,38 +1363,85 @@ sixel_quant_apply_palette(
         memset(new_palette, 0x00, sizeof(256 * depth));
         memset(migration_map, 0x00, sizeof(migration_map));
 
-        for (y = 0; y < height; ++y) {
-            for (x = 0; x < width; ++x) {
-                pos = y * width + x;
-                color_index = f_lookup(data + (pos * depth), depth,
-                                       palette, reqcolor, indextable, complexion);
-                if (migration_map[color_index] == 0) {
-                    result[pos] = *ncolors;
-                    for (n = 0; n < depth; ++n) {
-                        new_palette[*ncolors * depth + n] = palette[color_index * depth + n];
+        if (f_mask) {
+            for (y = 0; y < height; ++y) {
+                for (x = 0; x < width; ++x) {
+                    unsigned char copy[max_depth];
+                    int d;
+                    int val;
+
+                    pos = y * width + x;
+                    for (d = 0; d < depth; d ++) {
+                        val = data[pos * depth + d] + f_mask(x, y, d) * 32;
+                        copy[d] = val < 0 ? 0 : val > 255 ? 255 : val;
+                    }
+                    color_index = f_lookup(copy, depth,
+                                           palette, reqcolor, indextable, complexion);
+                    if (migration_map[color_index] == 0) {
+                        result[pos] = *ncolors;
+                        for (n = 0; n < depth; ++n) {
+                            new_palette[*ncolors * depth + n] = palette[color_index * depth + n];
+                        }
+                        ++*ncolors;
+                        migration_map[color_index] = *ncolors;
+                    } else {
+                        result[pos] = migration_map[color_index] - 1;
                     }
-                    ++*ncolors;
-                    migration_map[color_index] = *ncolors;
-                } else {
-                    result[pos] = migration_map[color_index] - 1;
-                }
-                for (n = 0; n < depth; ++n) {
-                    offset = data[pos * depth + n] - palette[color_index * depth + n];
-                    f_diffuse(data + n, width, height, x, y, depth, offset);
                 }
             }
+            memcpy(palette, new_palette, (size_t)(*ncolors * depth));
+        } else {
+            for (y = 0; y < height; ++y) {
+                for (x = 0; x < width; ++x) {
+                    pos = y * width + x;
+                    color_index = f_lookup(data + (pos * depth), depth,
+                                           palette, reqcolor, indextable, complexion);
+                    if (migration_map[color_index] == 0) {
+                        result[pos] = *ncolors;
+                        for (n = 0; n < depth; ++n) {
+                            new_palette[*ncolors * depth + n] = palette[color_index * depth + n];
+                        }
+                        ++*ncolors;
+                        migration_map[color_index] = *ncolors;
+                    } else {
+                        result[pos] = migration_map[color_index] - 1;
+                    }
+                    for (n = 0; n < depth; ++n) {
+                        offset = data[pos * depth + n] - palette[color_index * depth + n];
+                        f_diffuse(data + n, width, height, x, y, depth, offset);
+                    }
+                }
+            }
+            memcpy(palette, new_palette, (size_t)(*ncolors * depth));
         }
-        memcpy(palette, new_palette, (size_t)(*ncolors * depth));
     } else {
-        for (y = 0; y < height; ++y) {
-            for (x = 0; x < width; ++x) {
-                pos = y * width + x;
-                color_index = f_lookup(data + (pos * depth), depth,
-                                 palette, reqcolor, indextable, complexion);
-                result[pos] = color_index;
-                for (n = 0; n < depth; ++n) {
-                    offset = data[pos * depth + n] - palette[color_index * depth + n];
-                    f_diffuse(data + n, width, height, x, y, depth, offset);
+        if (f_mask) {
+            for (y = 0; y < height; ++y) {
+                for (x = 0; x < width; ++x) {
+                    unsigned char copy[max_depth];
+                    int d;
+                    int val;
+
+                    pos = y * width + x;
+                    for (d = 0; d < depth; d ++) {
+                        val = data[pos * depth + d] + f_mask(x, y, d) * 32;
+                        copy[d] = val < 0 ? 0 : val > 255 ? 255 : val;
+                    }
+                    result[pos] = f_lookup(copy, depth,
+                                           palette, reqcolor, indextable, complexion);
+                }
+            }
+        } else {
+            for (y = 0; y < height; ++y) {
+                for (x = 0; x < width; ++x) {
+                    pos = y * width + x;
+                    color_index = f_lookup(data + (pos * depth), depth,
+                                           palette, reqcolor, indextable, complexion);
+                    result[pos] = color_index;
+                    for (n = 0; n < depth; ++n) {
+                        offset = data[pos * depth + n] - palette[color_index * depth + n];
+                        f_diffuse(data + n, width, height, x, y, depth, offset);
+                    }
                 }
             }
         }
@@ -1411,7 +1488,7 @@ error:
 }
 
 
-int
+SIXELAPI int
 sixel_quant_tests_main(void)
 {
     int nret = EXIT_FAILURE;
