@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2016 Hayaki Saito
+ * Copyright (c) 2014-2018 Hayaki Saito
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy of
  * this software and associated documentation files (the "Software"), to deal in
@@ -311,7 +311,7 @@ error:
 }
 
 
-int
+SIXELAPI int
 sixel_status_tests_main(void)
 {
     int nret = EXIT_FAILURE;
